@@ -31,24 +31,6 @@ def _download(args):
 	
 	return urllib.urlopen(base + args).read()
 
-def _search(keywords):
-	"""
-		Returns the first hit's title page
-	"""
-	
-	args = {"action": "query",
-		"list": "search",
-		"srsearch": keywords,
-		"srlimit": 1,
-		"format": "json"
-		}
-	
-	response = json.loads(_download(args))["query"]["search"]
-	if len(response) > 0:
-		return response[0]["title"]
-	else:
-		return None
-
 def _get_lyrics(page_title):
 	args = {"action": "query",
 		"prop": "revisions",
@@ -66,17 +48,6 @@ def _get_lyrics(page_title):
 	if "<lyrics>" in content:
 		return content[content.find("<lyrics>") + len("<lyrics>") : content.find("</lyrics>")].strip()
 
-def search_for_lyrics(*keywords):
-	"""
-		Search for and return lyrics
-		keywords should include the title and artist
-	"""
-	title = _search(" ".join(keywords))
-	if not title:
-		return
-	
-	return _get_lyrics(title)
-
 def get_lyrics(artist, title):
 	"""
 		Get lyrics by artist and title
